@@ -33,15 +33,15 @@
 #include <KIconLoader>
 
 #include <QBoxLayout>
-#include <KLocale>
+
 using namespace EventViews;
 
 void WhatsNextTextBrowser::setSource(const QUrl &name)
 {
     QString uri = name.toString();
-    if (uri.startsWith(QStringLiteral("event:"))) {
+    if (uri.startsWith(QLatin1String("event:"))) {
         Q_EMIT showIncidence(uri);
-    } else if (uri.startsWith(QStringLiteral("todo:"))) {
+    } else if (uri.startsWith(QLatin1String("todo:"))) {
         Q_EMIT showIncidence(uri);
     } else {
         QTextBrowser::setSource(QUrl(uri));
@@ -101,20 +101,18 @@ void WhatsNextView::updateView()
         mText += QLocale::system().toString(mStartDate);
     } else {
         mText += i18nc(
-                     "date from - to", "%1 - %2",
-                     QLocale::system().toString(mStartDate),
-                     QLocale::system().toString(mEndDate));
+            "date from - to", "%1 - %2",
+            QLocale::system().toString(mStartDate),
+            QLocale::system().toString(mEndDate));
     }
     mText += QLatin1String("</h2>\n");
 
     KCalCore::Event::List events;
-    KDateTime::Spec timeSpec = CalendarSupport::KCalPrefs::instance()->timeSpec();
-
-    events = calendar()->events(mStartDate, mEndDate, timeSpec, false);
+    events = calendar()->events(mStartDate, mEndDate, QTimeZone::systemTimeZone(), false);
     events = calendar()->sortEvents(events, KCalCore::EventSortStartDate,
                                     KCalCore::SortDirectionAscending);
 
-    if (events.count() > 0) {
+    if (!events.isEmpty()) {
         mText += QLatin1String("<p></p>");
         kil->loadIcon(QStringLiteral("view-calendar-day"), KIconLoader::NoGroup, 22,
                       KIconLoader::DefaultState, QStringList(), &ipath);
@@ -129,13 +127,14 @@ void WhatsNextView::updateView()
             } else {
                 KCalCore::Recurrence *recur = ev->recurrence();
                 int duration = ev->dtStart().secsTo(ev->dtEnd());
-                KDateTime start = recur->getPreviousDateTime(KDateTime(mStartDate, QTime(), timeSpec));
-                KDateTime end = start.addSecs(duration);
-                KDateTime endDate(mEndDate, QTime(23, 59, 59), timeSpec);
+                QDateTime start
+                    = recur->getPreviousDateTime(QDateTime(mStartDate, QTime(), Qt::LocalTime));
+                QDateTime end = start.addSecs(duration);
+                QDateTime endDate(mEndDate, QTime(23, 59, 59), Qt::LocalTime);
                 if (end.date() >= mStartDate) {
-                    appendEvent(ev, start.toLocalZone().dateTime(), end.toLocalZone().dateTime());
+                    appendEvent(ev, start.toLocalTime(), end.toLocalTime());
                 }
-                KCalCore::DateTimeList times = recur->timesInInterval(start, endDate);
+                const auto times = recur->timesInInterval(start, endDate);
                 int count = times.count();
                 if (count > 0) {
                     int i = 0;
@@ -145,8 +144,8 @@ void WhatsNextView::updateView()
                     if (!times[count - 1].isValid()) {
                         --count;  // list overflow
                     }
-                    for (;  i < count && times[i].date() <= mEndDate;  ++i) {
-                        appendEvent(ev, times[i].toLocalZone().dateTime());
+                    for (; i < count && times[i].date() <= mEndDate; ++i) {
+                        appendEvent(ev, times[i].toLocalTime());
                     }
                 }
             }
@@ -156,8 +155,8 @@ void WhatsNextView::updateView()
 
     mTodos.clear();
     KCalCore::Todo::List todos = calendar()->todos(KCalCore::TodoSortDueDate,
-                                 KCalCore::SortDirectionAscending);
-    if (todos.count() > 0) {
+                                                   KCalCore::SortDirectionAscending);
+    if (!todos.isEmpty()) {
         bool taskHeaderWasCreated = false;
         Q_FOREACH (const KCalCore::Todo::Ptr &todo, todos) {
             if (!todo->isCompleted() && todo->hasDueDate() && todo->dtDue().date() <= mEndDate) {
@@ -190,7 +189,8 @@ void WhatsNextView::updateView()
 
     QStringList myEmails(CalendarSupport::KCalPrefs::instance()->allEmails());
     int replies = 0;
-    events = calendar()->events(QDate::currentDate(), QDate(2975, 12, 6), timeSpec);
+    events = calendar()->events(QDate::currentDate(), QDate(2975, 12, 6),
+                                QTimeZone::systemTimeZone());
     Q_FOREACH (const KCalCore::Event::Ptr &ev, events) {
         KCalCore::Attendee::Ptr me = ev->attendeeByMails(myEmails);
         if (me != nullptr) {
@@ -202,7 +202,8 @@ void WhatsNextView::updateView()
                     mText += QLatin1String("<h2><img src=\"");
                     mText += ipath;
                     mText += QLatin1String("\" width=\"22\" height=\"22\">");
-                    mText += i18n("Events and to-dos that need a reply:") + QLatin1String("</h2>\n");
+                    mText += i18n("Events and to-dos that need a reply:")
+                             + QLatin1String("</h2>\n");
                     mText += QLatin1String("<table>\n");
                 }
                 replies++;
@@ -222,7 +223,8 @@ void WhatsNextView::updateView()
                     mText += QLatin1String("<h2><img src=\"");
                     mText += ipath;
                     mText += QLatin1String("\" width=\"22\" height=\"22\">");
-                    mText += i18n("Events and to-dos that need a reply:") + QLatin1String("</h2>\n");
+                    mText += i18n("Events and to-dos that need a reply:")
+                             + QLatin1String("</h2>\n");
                     mText += QLatin1String("<table>\n");
                 }
                 replies++;
@@ -237,7 +239,6 @@ void WhatsNextView::updateView()
     mText += QLatin1String("</td></tr>\n</table>\n");
 
     mView->setText(mText);
-
 }
 
 void WhatsNextView::showDates(const QDate &start, const QDate &end, const QDate &)
@@ -254,7 +255,7 @@ void WhatsNextView::showIncidences(const Akonadi::Item::List &incidenceList, con
 }
 
 void WhatsNextView::changeIncidenceDisplay(const Akonadi::Item &,
-        Akonadi::IncidenceChanger::ChangeType)
+                                           Akonadi::IncidenceChanger::ChangeType)
 {
     updateView();
 }
@@ -266,7 +267,7 @@ void WhatsNextView::appendEvent(const KCalCore::Incidence::Ptr &incidence, const
     if (const KCalCore::Event::Ptr event = incidence.dynamicCast<KCalCore::Event>()) {
         auto starttime = start.toLocalTime();
         if (!starttime.isValid()) {
-            starttime = event->dtStart().dateTime().toLocalTime();
+            starttime = event->dtStart().toLocalTime();
         }
         auto endtime = end.toLocalTime();
         if (!endtime.isValid()) {
@@ -274,20 +275,26 @@ void WhatsNextView::appendEvent(const KCalCore::Incidence::Ptr &incidence, const
         }
 
         if (starttime.date().daysTo(endtime.date()) >= 1) {
-            if (event->allDay())
-                mText += i18nc("date from - to", "%1 - %2", QLocale().toString(starttime.date(), QLocale::ShortFormat),
-                               QLocale().toString(endtime.date(), QLocale::ShortFormat));
-            else
-                mText += i18nc("date from - to", "%1 - %2", QLocale().toString(starttime, QLocale::ShortFormat),
-                               QLocale().toString(endtime, QLocale::ShortFormat));
+            if (event->allDay()) {
+                mText
+                    += i18nc("date from - to", "%1 - %2",
+                             QLocale().toString(starttime.date(), QLocale::ShortFormat),
+                             QLocale().toString(endtime.date(), QLocale::ShortFormat));
+            } else {
+                mText
+                    += i18nc("date from - to", "%1 - %2", QLocale().toString(starttime,
+                                                                             QLocale::ShortFormat),
+                             QLocale().toString(endtime, QLocale::ShortFormat));
+            }
         } else {
-            if (event->allDay())
+            if (event->allDay()) {
                 mText += QLocale().toString(starttime.date(), QLocale::ShortFormat);
-            else
+            } else {
                 mText += i18nc("date, from - to", "%1, %2 - %3",
-                         QLocale().toString(starttime.date(), QLocale::ShortFormat),
-                         QLocale().toString(starttime.time(), QLocale::ShortFormat),
-                         QLocale().toString(endtime.time(), QLocale::ShortFormat));
+                               QLocale().toString(starttime.date(), QLocale::ShortFormat),
+                               QLocale().toString(starttime.time(), QLocale::ShortFormat),
+                               QLocale().toString(endtime.time(), QLocale::ShortFormat));
+            }
         }
     }
     mText += QLatin1String("</b></td><td><a ");
@@ -332,9 +339,9 @@ void WhatsNextView::showIncidence(const QString &uid)
         return;
     }
 
-    if (uid.startsWith(QStringLiteral("event:"))) {
+    if (uid.startsWith(QLatin1String("event:"))) {
         item = cal->item(uid.mid(6));
-    } else if (uid.startsWith(QStringLiteral("todo:"))) {
+    } else if (uid.startsWith(QLatin1String("todo:"))) {
         item = cal->item(uid.mid(5));
     }
 
@@ -342,4 +349,3 @@ void WhatsNextView::showIncidence(const QString &uid)
         Q_EMIT showIncidenceSignal(item);
     }
 }
-
